@@ -49,6 +49,8 @@
 #define gmtime_r(tp,tmp) (gmtime(tp)?(*(tmp)=*gmtime(tp),(tmp)):0)
 #endif
 
+G_DEFINE_TYPE (ECalBackendMAPI, e_cal_backend_mapi, E_TYPE_CAL_BACKEND_SYNC)
+
 typedef struct {
 	GCond *cond;
 	GMutex *mutex;
@@ -1606,7 +1608,7 @@ e_cal_backend_mapi_modify_object (ECalBackendSync *backend, EDataCal *cal, const
 
 	if (mod != CALOBJ_MOD_ALL) {
 		e_cal_backend_notify_error (E_CAL_BACKEND (cbmapi), _("Support for modifying single instances of a recurring appointment is not yet implemented. No change was made to the appointment on the server.")); 
-		return GNOME_Evolution_Calendar_Success;
+		return GNOME_Evolution_Calendar_OtherError;
 	}
 
 	/* check the component for validity */
@@ -1868,7 +1870,7 @@ e_cal_backend_mapi_send_objects (ECalBackendSync *backend, EDataCal *cal, const
 		icalcomponent *subcomp = icalcomponent_get_first_component (icalcomp, kind);
 		while (subcomp) {
 			ECalComponent *comp = e_cal_component_new ();
-			struct cbdata cbdata;
+			struct cbdata cbdata = { 0 };
 			mapi_id_t mid = 0;
 			GSList *recipients = NULL;
 			GSList *attachments = NULL;
@@ -2022,8 +2024,19 @@ e_cal_backend_mapi_receive_objects (ECalBackendSync *backend, EDataCal *cal, con
 
 			switch (method) {
 			case ICAL_METHOD_REQUEST :
-				comp_str = e_cal_component_get_as_string (comp);
-				status = e_cal_backend_mapi_modify_object (backend, cal, comp_str, CALOBJ_MOD_THIS, &old_object, &new_object);
+				comp_str = NULL;
+				status = e_cal_backend_mapi_get_object (backend, cal, uid, NULL, &comp_str);
+				if (status != GNOME_Evolution_Calendar_Success) {
+					comp_str = e_cal_component_get_as_string (comp);
+					new_object = comp_str;
+					status = e_cal_backend_mapi_create_object (backend, cal, &new_object, NULL);
+					if (new_object == comp_str)
+						new_object = NULL;
+				} else {
+					g_free (comp_str);
+					comp_str = e_cal_component_get_as_string (comp);
+					status = e_cal_backend_mapi_modify_object (backend, cal, comp_str, CALOBJ_MOD_ALL, &old_object, &new_object);
+				}
 				g_free (comp_str);
 				g_free (old_object);
 				g_free (new_object);
@@ -2442,7 +2455,7 @@ e_cal_backend_mapi_class_init (ECalBackendMAPIClass *class)
 
 
 static void
-e_cal_backend_mapi_init (ECalBackendMAPI *cbmapi, ECalBackendMAPIClass *class)
+e_cal_backend_mapi_init (ECalBackendMAPI *cbmapi)
 {
 	ECalBackendMAPIPrivate *priv;
 	
@@ -2459,30 +2472,6 @@ e_cal_backend_mapi_init (ECalBackendMAPI *cbmapi, ECalBackendMAPIClass *class)
 	e_cal_backend_sync_set_lock (E_CAL_BACKEND_SYNC (cbmapi), TRUE);
 }
 
-GType
-e_cal_backend_mapi_get_type (void)
-{
-	static GType e_cal_backend_mapi_type = 0;
-
-	if (!e_cal_backend_mapi_type) {
-		static GTypeInfo info = {
-                        sizeof (ECalBackendMAPIClass),
-                        (GBaseInitFunc) NULL,
-                        (GBaseFinalizeFunc) NULL,
-                        (GClassInitFunc) e_cal_backend_mapi_class_init,
-                        NULL, NULL,
-                        sizeof (ECalBackendMAPI),
-                        0,
-                        (GInstanceInitFunc) e_cal_backend_mapi_init
-                };
-		e_cal_backend_mapi_type = g_type_register_static (E_TYPE_CAL_BACKEND_SYNC,
-								  "ECalBackendMAPI", &info, 0);
-	}
-
-	return e_cal_backend_mapi_type;
-}
-
-
 /***** UTILITY FUNCTIONS *****/
 const char *	
 e_cal_backend_mapi_get_local_attachments_store (ECalBackendMAPI *cbmapi)
