@@ -44,11 +44,33 @@
 gchar *
 utf8tolinux (const char *wstring)
 {
+	#ifndef HAVE_WINDOWS_TO_UTF8
+	/* newer Openchange (0.10+) doesn't provide windows_to_utf8 function,
+	   it does all the necessary decoding to utf8 transparently */
+	return g_strdup (wstring);
+	#else
 	TALLOC_CTX 	*mem_ctx;
 	gchar		*newstr, *retval = NULL;
+	gint i;
+	gboolean all_ok = TRUE;
 
 	g_return_val_if_fail (wstring != NULL, NULL);
 
+	/* If all letters are with code <128 then there is nothing
+	   to be converted, thus return the original string copy.
+	   It's not working always, but should be fine for now.
+
+	   This is a temporary hack before the windows_to_utf8 will
+	   be fixed to not drop some letters.
+	*/
+	for (i = 0; all_ok && wstring[i]; i++) {
+		/* signed char, thus '> 128' means '< 0' */
+		all_ok = wstring[i] > 0;
+	}
+
+	if (all_ok)
+		return g_strdup (wstring);
+
 	mem_ctx = talloc_init ("ExchangeMAPI_utf8tolinux");
 
 	newstr = windows_to_utf8(mem_ctx, wstring);
@@ -61,6 +83,7 @@ utf8tolinux (const char *wstring)
 	talloc_free (mem_ctx);
 
 	return retval;
+	#endif
 }
 
 inline gchar *
@@ -270,8 +293,8 @@ exchange_mapi_util_free_recipient_list (GSList **recip_list)
 			g_free (recipient->in.ext_lpProps);
 		if (recipient->in.req_cValues)
 			g_free (recipient->in.req_lpProps);
-/*		if (recipient->out.all_cValues)
-			g_free (recipient->out.all_lpProps);
+/*		if (recipient->out_SRow.cValues)
+			g_free (recipient->out_SRow.lpProps);
 */		g_free (recipient);
 	}
 	g_slist_free (*recip_list);
